summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqframe.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqframe.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqframe.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqframe.cpp b/tqtinterface/qt4/src/widgets/tqframe.cpp
index f49b30c..4bce9b1 100644
--- a/tqtinterface/qt4/src/widgets/tqframe.cpp
+++ b/tqtinterface/qt4/src/widgets/tqframe.cpp
@@ -476,18 +476,18 @@ TQRect TQFrame::contentsRect() const
/*!\reimp
*/
-TQSize TQFrame::tqsizeHint() const
+TQSize TQFrame::sizeHint() const
{
// Returns a size hint for the frame - for HLine and VLine
// tqshapes, this is stretchable one way and 3 pixels wide the
// other. For other tqshapes, TQWidget::tqsizeHint() is used.
switch (fstyle & MShape) {
case HLine:
return TQSize(-1,3);
case VLine:
return TQSize(3,-1);
default:
- return TQWidget::tqsizeHint();
+ return TQWidget::sizeHint();
}
}
@@ -476,18 +476,18 @@ TQRect TQFrame::contentsRect() const
// Returns a size hint for the frame - for HLine and VLine
// tqshapes, this is stretchable one way and 3 pixels wide the
- // other. For other tqshapes, TQWidget::tqsizeHint() is used.
+ // other. For other tqshapes, TQWidget::sizeHint() is used.
switch (fstyle & MShape) {
case HLine: